EasyBaseWidget<T> class abstract

Base widget for Easy components providing shared APIs.

Inheritance
Implementers

Constructors

EasyBaseWidget({Key? key, required List<T> items, required EasyItemBuilder<T> itemBuilder, EasyLabelBuilder<T>? labelBuilder, T? value, ValueChanged<T?>? onChanged, EasyIsEqual<T>? isEqual, bool multiSelect = false, List<T>? selectedValues, ValueChanged<List<T>>? onChangedMultiple})
Default constructor for EasyBaseWidget.

Properties

hashCode int
The hash code for this object.
no setterinherited
isEqual EasyIsEqual<T>
A function that checks whether two items are considered equal.
final
itemBuilder EasyItemBuilder<T>
The builder used to construct each item in the UI.
final
items List<T>
The list of items to select from.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelBuilder EasyLabelBuilder<T>?
An optional builder to extract a string label from an item.
final
multiSelect bool
Whether the widget supports selecting multiple values.
final
onChanged ValueChanged<T?>?
Callback when a single item is selected.
final
onChangedMultiple ValueChanged<List<T>>?
Callback when multiple items are selected.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedValues List<T>
The currently selected values (multi-select).
final
value → T?
The currently selected value (single-select).
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildField(BuildContext context) Widget
Subclasses must override this to build the inner field ui.
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited