EasyRadioGroup<T> class

Inheritance

Constructors

EasyRadioGroup({Key? key, required List<T> items, required EasyItemBuilder<T> itemBuilder, EasyLabelBuilder<T>? labelBuilder, T? value, ValueChanged<T?>? onChanged, EasyIsEqual<T>? isEqual, bool multiSelect = false, List<T>? selectedValues, ValueChanged<List<T>>? onChangedMultiple, bool wrap = false, double spacing = 8})

Properties

hashCode int
The hash code for this object.
no setterinherited
isEqual EasyIsEqual<T>
A function that checks whether two items are considered equal.
finalinherited
itemBuilder EasyItemBuilder<T>
The builder used to construct each item in the UI.
finalinherited
items List<T>
The list of items to select from.
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelBuilder EasyLabelBuilder<T>?
An optional builder to extract a string label from an item.
finalinherited
multiSelect bool
Whether the widget supports selecting multiple values.
finalinherited
onChanged ValueChanged<T?>?
Callback when a single item is selected.
finalinherited
onChangedMultiple ValueChanged<List<T>>?
Callback when multiple items are selected.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedValues List<T>
The currently selected values (multi-select).
finalinherited
spacing double
final
value → T?
The currently selected value (single-select).
finalinherited
wrap bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildField(BuildContext context) Widget
Subclasses must override this to build the inner field ui.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited