EasySearchMultiSelectSheet<T> class

Inheritance

Constructors

EasySearchMultiSelectSheet({Key? key, required List<T> items, required List<T> initialSelectedItems, required String getSearchText(T), required void onConfirm(List<T> selected), Widget itemBuilder(T, bool)?, String title = 'Select Items', String searchHint = 'Search...', IconData titleIcon = Icons.list, Widget recommendationBuilder(List<T> selectedItems, void toggleSelection(T item))?, String confirmButtonTextBuilder(int)?})
const

Properties

confirmButtonTextBuilder String Function(int)
final
getSearchText String Function(T)
final
hashCode int
The hash code for this object.
no setterinherited
initialSelectedItems List<T>
final
itemBuilder Widget Function(T, bool)?
final
items List<T>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onConfirm → void Function(List<T> selected)
final
recommendationBuilder Widget Function(List<T> selectedItems, void toggleSelection(T item))?
An optional builder to show recommendations with access to the current selection.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHint String
final
title String
final
titleIcon IconData
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<EasySearchMultiSelectSheet<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show<T>({required BuildContext context, required List<T> items, required List<T> initialSelectedItems, required String getSearchText(T), Widget itemBuilder(T, bool)?, String title = 'Select Items', String searchHint = 'Search...', IconData titleIcon = Icons.list, Widget recommendationBuilder(List<T> selectedItems, void toggleSelection(T item))?, String confirmButtonTextBuilder(int)?, bool isScrollControlled = true, bool useSafeArea = true, double initialChildSize = 0.65, double minChildSize = 0.4, double maxChildSize = 0.92}) Future<List<T>?>
Convenience method to show the sheet