recommendationBuilder property
An optional builder to show recommendations with access to the current selection.
Implementation
final Widget Function(List<T> selectedItems, void Function(T item) toggleSelection)? recommendationBuilder;
An optional builder to show recommendations with access to the current selection.
final Widget Function(List<T> selectedItems, void Function(T item) toggleSelection)? recommendationBuilder;