EasySelectionController<T> class
Base controller shared across widgets for synchronised value handling. Base controller shared across widgets for synchronised value handling.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
T?> - EasySelectionController
Constructors
-
EasySelectionController({T? value, EasyIsEqual<
T> ? isEqual}) - Creates an EasySelectionController with an optional initial value and equality checker.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ T?
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
isSelected(
T? other) → bool -
Returns true if
otheris considered selected. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
select(
T? next) → void -
Selects the
nextvalue if it differs from the current one. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited