own
library
Functions
defaultEasyEquals <T > ()
→ EasyIsEqual <T >
Returns a default equality checker that uses the == operator.
easyBottomSheetSelectOf <T > ({required List <T > items , T? value , List <T > ? values , ValueChanged <T? > ? onChanged , ValueChanged <List <T > > ? onChangedMany , bool multiSelect = false , String label (T )?, Widget ? sheetTitle })
→ Widget
Easy bottom sheet selector.
easyButtonGroupOf <T > ({required List <T > items , T? value , List <T > ? values , ValueChanged <T? > ? onChanged , ValueChanged <List <T > > ? onChangedMany , bool multiSelect = false , String label (T )? })
→ Widget
Easy button group (ChoiceChip-like) from values.
easyCheckboxOf <T > ({required List <T > items , T? value , List <T > ? values , ValueChanged <T? > ? onChanged , ValueChanged <List <T > > ? onChangedMany , bool multiSelect = false , String label (T )? })
→ Widget
Easy multi/single checkbox list with minimal config.
easyChipsOf <T > ({required List <T > items , T? value , List <T > ? values , ValueChanged <T? > ? onChanged , ValueChanged <List <T > > ? onChangedMany , bool multiSelect = false , String label (T )? })
→ Widget
Easy chips selection from values.
easyDateFieldOf ({required DateTime ? value , required ValueChanged <DateTime ? > onChanged , String label (DateTime )?, DateTime ? firstDate , DateTime ? lastDate , DateTime ? initialDate })
→ Widget
Easy date field that opens a date picker on tap.
easyDoubleFieldOf ({required double ? value , required ValueChanged <double ? > ? onChanged , String ? hintText })
→ Widget
Convenient double text field with numeric keyboard and parsing.
easyDropdownOf <T > ({required List <T > items , T? value , ValueChanged <T? > ? onChanged , String label (T )? })
→ Widget
Easy dropdown: just pass items, current value and onChanged.
easyIntFieldOf ({required int ? value , required ValueChanged <int ? > ? onChanged , String ? hintText })
→ Widget
Convenient integer text field with numeric keyboard and parsing.
easyListOf <T > ({required List <T > items , T? value , ValueChanged <T? > ? onChanged , bool multiSelect = false , List <T > ? values , ValueChanged <List <T > > ? onChangedMany , String label (T )?, bool divided = true , bool dense = false })
→ Widget
Easy selectable list with generic items.
Easy popup menu for single-select actions.
Easy popup selector using the advanced popup dialog.
easyRadioOf <T > ({required List <T > items , T? value , ValueChanged <T? > ? onChanged , String label (T )? })
→ Widget
Easy radio group with just items, selected value and onChanged.
easySearchOf <T > ({required List <T > items , required String label (T ), void onSelected (T selectedItem )?, void onSelectedMany (List <T > selectedItems )?, bool multiSelect = false , SearchRemoteResolver <T > ? remoteSearch , String hintText = 'Search...' })
→ Widget
Easy search + recommendation widget:
just pass items, label mapper and callbacks.
easySegmentedOf <T > ({required List <T > items , T? value , ValueChanged <T? > ? onChanged , bool multiSelect = false , List <T > ? values , String label (T )? })
→ Widget
Easy segmented control with generic items and selection.
easySwitchOf <T > ({required List <T > items , T? value , List <T > ? values , ValueChanged <T? > ? onChanged , ValueChanged <List <T > > ? onChangedMany , bool multiSelect = false , String label (T )? })
→ Widget
Easy switch group for toggling one or many options.
easyTableOf <T > ({required List <T > items , required List <DataColumn > columns , required EasyTableCellBuilder <T > cellBuilder , T? value , ValueChanged <T? > ? onChanged , EasyIsEqual <T > ? isEqual , bool multiSelect = false , List <T > ? selectedValues , ValueChanged <List <T > > ? onChangedMany , bool showCheckboxColumn = true , double ? dataRowHeight , double ? headingRowHeight })
→ Widget
Easy table convenience for quick rendering.
easyTextFieldOf <T > ({required T? value , required ValueChanged <T? > ? onChanged , String label (T )?, T? parser (String text )?, String ? hintText , TextInputType ? keyboardType , bool obscureText = false })
→ Widget
Easy text field bound directly to a value of type T.
easyTextFormFieldOf <T > ({required EasyFormController form , required String name , String label (T )?, T? parser (String text )?, String ? hintText , TextInputType ? keyboardType , bool obscureText = false })
→ Widget
Easy TextFormField bound to an EasyFormController and field name.
Typedefs
DateFormatter
= String Function(DateTime value )
Formats a DateTime value into a human-readable String .
EasyDecorationBuilder
= BoxDecoration Function(bool isExpanded , bool hasValue )
EasyFilePickHandler <T >
= FutureOr <List <T > > Function(EasyFileCategory category , bool allowMultiple )
EasyIconBuilder
= Widget Function(bool isExpanded )
A builder that defines the icon to show in the dropdown.
EasyImagePickHandler <T >
= FutureOr <List <T > > Function(EasyImageSource source , bool allowMultiple )
EasyIsEqual <T >
= bool Function(T? a , T? b )
A function signature for checking equality between two elements of type T.
EasyItemBuilder <T >
= Widget Function(BuildContext context , T item , bool isSelected )
A builder that creates a widget for a given item, indicating its selection state.
EasyLabelBuilder <T >
= String Function(T item )
A builder that extracts a displayable string label from an item.
EasyMultiBuilder <T >
= Widget Function(BuildContext context , List <T > values , ValueChanged <List <T > > onChanged )
A builder for multi-selection widgets using state bridges.
EasySingleBuilder <T >
= Widget Function(BuildContext context , T? value , ValueChanged <T? > onChanged )
A builder for single-selection widgets using state bridges.
EasyStyleBuilder <T >
= TextStyle ? Function(T? value , bool isExpanded )
A builder that defines the TextStyle for the dropdown's text.
EasyTableCellBuilder <T >
= Widget Function(BuildContext context , T row , int columnIndex , bool selected )
EasyValidator <T >
= String ? Function(T? value )
Signature for validating a value of type T. Return null when valid.
EasyValueParser <T >
= T? Function(String text )
SearchRemoteResolver <T >
= Future <List <T > > Function(String query )
Optional remote search callback used for server-side searching.